@@ -1,3 +1,7 @@
+"""
+Apypie - Apipie bindings for Python
+"""
+
 from __future__ import print_function, absolute_import
 
 from apypie.resource import Resource
@@ -8,4 +12,4 @@ from apypie.example import Example
 from apypie.param import Param
 from apypie.inflector import Inflector
 
-__all__ = [Api, Resource, Route, Action, Example, Param, Inflector]
+__all__ = ['Api', 'Resource', 'Route', 'Action', 'Example', 'Param', 'Inflector']
